
(_api_geodetic)=
# Geodetic

## Specialized Instances
```{eval-rst}
.. autoclass:: sasktran2.WGS84

.. autoclass:: sasktran2.SphericalGeoid

```

## sk.Geodetic

```{eval-rst}
.. autoclass:: sasktran2.Geodetic
```
